#!/usr/bin/env python3

"""Create VM Deployment in MeX via API

This script will allow the user to create a VM
deployment using the MeX API.

This is a POC only, and is not intended for production use:
  - All variables are hardcoded into this script.
  - Credentials are stored in this script.
  - No error handling is present in this code.
  - The script is devoid of functions and is pretty stupid.

The script assumes you have built and pushed to the MeX artifactory
registry a vm that matches the variables below. It also
assumes that you have an account and that you have put the
credentials in the script.

Additionally, this script does not handle the building of the
image or the pushing of the image to the artifactory repository

JAS 9-Apr-2020
"""



import simplejson as json
import requests


## MEX Variables
ACCPORTS = "TCP:22"
ACCTYPE = 0
ALLIP = "dynamic"
APPNAME = "vmtwo"
APPVER = "1.0"
CLDLET = "munich-main"
CLSTR = "DefaultVMCluster"
DEPMAN = "#cloud-config\r\n        user: demouser\r\n        password: NoMoreSecret3\r\n        chpasswd: {expire: False}\r\n        ssh_pwauth: True"
FLAVOR = "m4.small"
IMGPATH = "https://artifactory.mobiledgex.net/artifactory/repo-demoorg/CentOS-7-x86_64-GenericCloud-1905.qcow2#md5:ec8c38b1656ded3e03a6dc0938e201f1"
IMGTYPE = 2
INTPORTS = True
IPACC = 1
MEXPASS = "helloworld"
MEXUSER = "demo"
OPKEY = "TDG"
ORG = "demoorg"
REGION = "EU"
REV = 0
TYPE = "vm"

## Call Variables
HEADERS = {'Content-Type': 'application/json'}

########################################################
## Login

# Endpoint / Route
url = "https://console.mobiledgex.net/api/v1/login"

# Payload
payload = {
  "username": MEXUSER,
  "password": MEXPASS
}

payload_json = json.dumps(payload)  # Convert dict to json string

# Call the API and parse out the token
response = requests.post(url, data=payload_json, headers=HEADERS)
parsed = json.loads(response.text)
thetoken = (parsed['token'])

# Build our header
bt = "Bearer " + thetoken

# Add to our headers
HEADERS['Authorization'] = bt



########################################################
## Create App Section

print("Creating the application...")

# Endpoint / Route
url = "https://console.mobiledgex.net/api/v1/auth/ctrl/CreateApp"


# Payload
payload = {
"Region": REGION,
"App": {
  "key": {
    "developer_key" : {
      "name": ORG
    },
    "name": APPNAME,
    "organization": ORG,
    "version": APPVER
  },
  "deployment": TYPE,
  "access_type": ACCTYPE,
  "image_path": IMGPATH,
  "image_type": IMGTYPE,
  "internal_ports": INTPORTS,
  "default_flavor": {
    "name": FLAVOR,
  },
  "revision": REV,
  "access_ports": ACCPORTS,
  "deployment_manifest": DEPMAN
}
}


# Convert dict to json string
payload_json = json.dumps(payload)

# Call the API
response = requests.post(url, data=payload_json, headers=HEADERS)

# Print the response
print(response.text)

########################################################
# Create AppInst Section

print("Creating the AppInst...")

# Endpoint / Route
url = "https://console.mobiledgex.net/api/v1/auth/ctrl/CreateAppInst"

# Payload
payload = {
  "Region": REGION,
  "AppInst": {
    "key": {
      "app_key": {
        "organization": ORG,
        "name": APPNAME,
        "version": APPVER,
        "developer_key": {
          "name": ORG
        }
      },
      "cluster_inst_key": {
        "cluster_key": {
          "name": CLSTR
        },
        "cloudlet_key": {
          "operator_key": {
            "name": OPKEY
          },
          "name": CLDLET
        },
        "developer": ORG
      }
    },
    "flavor": {
      "name": FLAVOR
    }
  }
}


# Convert dict to json string
payload_json = json.dumps(payload)

# Call the API
response = requests.post(url, data=payload_json, headers=HEADERS)

# Print the response
print(response.text)
